sdv.sampling.Condition
======================

.. currentmodule:: sdv.sampling

.. autoclass:: Condition

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Condition.__init__
      ~Condition.get_column_values
      ~Condition.get_num_rows
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Condition.column_values
      ~Condition.num_rows
   
   